==> cxf-testutils-2.0.6.10-fuse-sources.jar: org/apache/type_test/doc/TestSimpleContent1.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.SimpleContent1;


/**
 * <p>Java class for testSimpleContent1 element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testSimpleContent1">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}SimpleContent1"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}SimpleContent1"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testSimpleContent1")
public class TestSimpleContent1 {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected SimpleContent1 x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected SimpleContent1 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContent1 }
     *     
     */
    public SimpleContent1 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContent1 }
     *     
     */
    public void setX(SimpleContent1 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContent1 }
     *     
     */
    public SimpleContent1 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContent1 }
     *     
     */
    public void setY(SimpleContent1 value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.20-fuse-sources.jar: org/apache/type_test/doc/TestSimpleContent1.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.SimpleContent1;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}SimpleContent1"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}SimpleContent1"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testSimpleContent1")
public class TestSimpleContent1 {

    @XmlElement(required = true)
    protected SimpleContent1 x;
    @XmlElement(required = true)
    protected SimpleContent1 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContent1 }
     *     
     */
    public SimpleContent1 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContent1 }
     *     
     */
    public void setX(SimpleContent1 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContent1 }
     *     
     */
    public SimpleContent1 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContent1 }
     *     
     */
    public void setY(SimpleContent1 value) {
        this.y = value;
    }

}
